Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(905)

Unified Diff: runtime/vm/intermediate_language.cc

Issue 10877030: Fix inlining and intrinsification for moved Math methods. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/intermediate_language.h ('k') | runtime/vm/intrinsifier.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/intermediate_language.cc
===================================================================
--- runtime/vm/intermediate_language.cc (revision 11200)
+++ runtime/vm/intermediate_language.cc (working copy)
@@ -151,12 +151,14 @@
MethodRecognizer::Kind MethodRecognizer::RecognizeKind(
const Function& function) {
// Only core library methods can be recognized.
const Library& core_lib = Library::Handle(Library::CoreLibrary());
const Library& core_impl_lib = Library::Handle(Library::CoreImplLibrary());
+ const Library& math_lib = Library::Handle(Library::MathLibrary());
const Class& function_class = Class::Handle(function.Owner());
if ((function_class.library() != core_lib.raw()) &&
- (function_class.library() != core_impl_lib.raw())) {
+ (function_class.library() != core_impl_lib.raw()) &&
+ (function_class.library() != math_lib.raw())) {
return kUnknown;
}
const String& recognize_name = String::Handle(function.name());
@@ -151,12 +151,14 @@
MethodRecognizer::Kind MethodRecognizer::RecognizeKind(
const Function& function) {
- // Only core library methods can be recognized.
+ // Only core and math library methods can be recognized.
const Library& core_lib = Library::Handle(Library::CoreLibrary());
const Library& core_impl_lib = Library::Handle(Library::CoreImplLibrary());
« no previous file with comments | « runtime/vm/intermediate_language.h ('k') | runtime/vm/intrinsifier.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698